package com.example.tdl.web;


import com.alibaba.fastjson.JSON;
import com.alibaba.fastjson.JSONObject;
import com.example.tdl.domain.dto.CommFeedback;
import com.example.tdl.domain.vo.*;
import com.example.tdl.entity.Alarm;
import com.example.tdl.entity.Gateway;
import com.example.tdl.service.*;
import com.example.tdl.service.redis.InfoRedisService;
import com.example.tdl.service.redis.TokenRedisService;
import com.google.gson.Gson;
import io.swagger.annotations.ApiImplicitParam;
import io.swagger.annotations.ApiImplicitParams;
import io.swagger.annotations.ApiOperation;
import org.apache.commons.lang3.StringUtils;
import org.influxdb.dto.Query;
import org.influxdb.dto.QueryResult;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.data.influxdb.InfluxDBTemplate;
import org.springframework.web.bind.annotation.*;

import javax.print.attribute.standard.RequestingUserName;
import javax.servlet.http.HttpServletRequest;
import java.text.ParseException;
import java.text.SimpleDateFormat;
import java.util.*;

@RestController
@RequestMapping("/warehouse")
public class WarehouseController {

    private Logger logger = LoggerFactory.getLogger(WarehouseController.class);

    CommFeedback fb=new CommFeedback();

    Gson gson=new Gson();

    @Autowired
    private WarehouseService warehouseService=new WarehouseService();

    @Autowired
    private TokenRedisService tokenRedisService;

    @Autowired
    private AlarmService alarmService;

    @Autowired
    private I18nController i18n;

    @Autowired
    private GatewayService gatewayService;

    @Autowired
    private TDLDeviceService tdlDeviceService;

    @Autowired
    private InfoRedisService infoRedisService;

    @Autowired
    private UserService userService;

    @Autowired
    private InfluxDBTemplate influxDBTemplate;

    private final static String database ="original";

    //查询所有仓库信息
    @ApiOperation(value = "查询所有仓库信息",notes = "查询所有仓库信息,返回值说明：" +
            "   warehouseName:仓库名," +
            "   warehouseNo:仓库编号," +
            "   img:图片路径" +
            "   country:国家," +
            "   city:市," +
            "   regions:国家地区," +
            "   addressDetail:具体地址," +
            "   regionName:区域," +
            "   lng:经度," +
            "   lat:纬度," +
            "   property:属性," +
            "   type:类型," +
            "   alarmType:预警类型," +
            "   hardwareLevel:硬件等级," +
            "   areaIndoor:室内平面面积," +
            "   areaRack:货架面积," +
            "   areaOutdoor:室外面积," +
            "   areaPlanIndoor:实际室内总面积," +
            "   office:办事处," +
            "   timeZone:时区," +
            "   companyName:所属公司," +
            "   warehouseInfo:基础描述," +
            "   remark:备注")
    @ApiImplicitParams({
            @ApiImplicitParam(paramType="header", name = "Account_token", value = "token", required = true, dataType = "String"),
    })
    @RequestMapping(value="/getAll",method = RequestMethod.GET)
    public Object getAll(HttpServletRequest request){
        String token = request.getHeader("Account_token");
        String datum = tokenRedisService.get("TOKEN_" +token);
        UserRedisVo userRedisVo = gson.fromJson(datum,UserRedisVo.class);
        return warehouseService.getAll(userRedisVo.getCompanyName());
    }

    //根据条件查询仓库信息
    @ApiOperation(value = "根据条件查询仓库信息",notes = "根据条件查询仓库信息,传值说明：" +
            "   warehouseName:仓库名," +
            "   country:国家," +
            "   city:市," +
            "   property:属性," +
            "   type:,仓库类型" +
            "   hardwareLevel:硬件等级。(查询全部传{})" +
            "返回值说明：" +
            "   warehouseName:仓库名," +
            "   warehouseNo:仓库编号," +
            "   country:国家," +
            "   city:市," +
            "   regions:国家地区," +
            "   addressDetail:具体地址," +
            "   regionName:区域," +
            "   lng:经度," +
            "   lat:纬度," +
            "   property:属性," +
            "   type:类型," +
            "   alarmType:预警类型," +
            "   alarmScene:预警场景," +
            "   hardwareLevel:硬件等级," +
            "   areaIndoor:室内平面面积," +
            "   areaRack:货架面积," +
            "   areaOutdoor:室外面积," +
            "   areaPlanIndoor:实际室内总面积," +
            "   office:办事处," +
            "   timeZone:时区," +
            "   companyName:公司," +
            "   warehouseInfo:基础描述," +
            "   remark:备注")
    @ApiImplicitParams({
            @ApiImplicitParam(paramType="header", name = "Account_token", value = "token", required = true, dataType = "String"),
    })
    @PostMapping(value="/getWarehouseByTerm")
    public Object getWarehouseByTerm(@RequestBody WarehouseTermVo warehouseTermVo,HttpServletRequest request){
        String token = request.getHeader("Account_token");
        String datum = tokenRedisService.get("TOKEN_" +token);
        UserRedisVo userRedisVo = gson.fromJson(datum,UserRedisVo.class);
        warehouseTermVo.setCompanyName(userRedisVo.getCompanyName());
        return warehouseService.getAllByTerm(warehouseTermVo);
    }

    //获取仓库以及设备数据
    @ApiOperation(value = "获取仓库以及设备数据",notes = "获取仓库以及设备数据,传值说明：" +
            "   warehouseName:仓库名," +
            "   country:国家," +
            "   city:市," +
            "   alarm:预警(查询全部传{})" +
            "返回值:"+
            "   warehouseName:仓库名," +
            "   warehouseNo:仓库编号," +
            "   regions:国家地区," +
            "   counts:设备数量," +
            "   temp:当前温度," +
            "   humidity:当前温度" )
    @ApiImplicitParams({
            @ApiImplicitParam(paramType="header", name = "Account_token", value = "token", required = true, dataType = "String"),
    })
    @PostMapping(value="/getByTerm")
    public Object getByTerm(@RequestBody WareHouseByTermVo warehouseTermVo,HttpServletRequest request){
        String token = request.getHeader("Account_token");
        String datum = tokenRedisService.get("TOKEN_" +token);
        UserRedisVo userRedisVo = gson.fromJson(datum,UserRedisVo.class);
        warehouseTermVo.setCompanyName(userRedisVo.getCompanyName());
        List<SimpleWarehouseVo>  simpleWarehouseVos = warehouseService.getByWarehouse(warehouseTermVo);
        for( int i = 0,length= simpleWarehouseVos.size();i<length;i++ ){
            //判断是否已经绑定设备
            if(simpleWarehouseVos.get(i).getCount() == 0){
                simpleWarehouseVos.get(i).setTemp("~");
                simpleWarehouseVos.get(i).setTemp("~");
                continue;
            }
            List<DeviceVo>  list = warehouseService.getDevice(simpleWarehouseVos.get(i).getWarehouseNo());
            if(list.size() == 0){
                simpleWarehouseVos.get(i).setTemp("~");
                simpleWarehouseVos.get(i).setTemp("~");
                continue;
            }
            String  sql = "";
            for(int j = 0,len=list.size();j<len;j++){
                if( StringUtils.isEmpty(list.get(i).getTdl())){
                    simpleWarehouseVos.get(i).setTemp("~");
                    simpleWarehouseVos.get(i).setTemp("~");
                    continue;
                }
                Long time = (System.currentTimeMillis()-10*60*1000)*1000000l;
                String tdl  = list.get(i).getTdl();
                String t = tdl.replace(",","\' or \"tdl\" = \'");
//                sql = "SELECT \"T\",\"h\" FROM \"tdl_policy\".\"WTD93LG_17110194\"  where  \"tdl\" = \'TDL-1706190193608\' or \"tdl\" = \'TDL-1701110082608\' GROUP BY \"tdl\"  order by time  desc limit 1";
               sql = "SELECT \"T\",\"h\" FROM \"tdl_policy\".\""+list.get(i).getDevice()+"\"  where  \"tdl\" = \'"+ t  +"\' GROUP BY \"tdl\"  order by time  desc limit 1";
            }
            if(StringUtils.isEmpty(sql)){
                simpleWarehouseVos.get(i).setTemp("~");
                simpleWarehouseVos.get(i).setTemp("~");
                continue;
            }
            QueryResult queryResult  = influxDBTemplate.query(new Query(sql,database));
            if(queryResult.getResults().get(0).getSeries()== null){
                simpleWarehouseVos.get(i).setTemp("~");
                simpleWarehouseVos.get(i).setTemp("~");
                continue;
            }
            //解析温湿度数据
            SimpleWarehouseVo simpleWarehouseVo =   dataData(queryResult);
            simpleWarehouseVos.get(i).setHumidity(simpleWarehouseVo.getHumidity());
            simpleWarehouseVos.get(i).setTemp(simpleWarehouseVo.getTemp());

        }
        return  simpleWarehouseVos;
    }

    //根据仓库编号获取仓库信息
    @ApiOperation(value = "根据仓库编号获取仓库信息",notes = "根据仓库编号获取仓库信息,传值说明：")
    @ApiImplicitParams({
            @ApiImplicitParam(paramType="header", name = "Account_token", value = "token", required = true, dataType = "String"),
    })
    @PostMapping("/getDetails")
    public Object getDetails(@RequestBody String warehouseNo,HttpServletRequest request){
        String token = request.getHeader("Account_token");
        String datum = tokenRedisService.get("TOKEN_" +token);
        UserRedisVo userRedisVo = gson.fromJson(datum,UserRedisVo.class);
        JSONObject jsonObject=JSON.parseObject(warehouseNo);
        warehouseNo=(String) jsonObject.get("warehouseNo");
        WarehouseDetailVo warehouseDetailVo=warehouseService.getWarehouseDetailByNo(warehouseNo);
        List<GatewayOnLineVo> gatewayOnLineVos=gatewayService.getByWarehouseNo(warehouseNo);
        for (int a=0;a<gatewayOnLineVos.size();a++){
            String device = gatewayOnLineVos.get(a).getType() + "_" + gatewayOnLineVos.get(a).getSN();
            Object data = infoRedisService.getHash("DeviceOnline", device );
            if(data !=null){
                OnlineVo onlineVo =  gson.fromJson(data.toString(),OnlineVo.class);
                if(onlineVo.getOnline() == 1){
                    gatewayOnLineVos.get(a).setState(7);
                }else {
                    gatewayOnLineVos.get(a).setState(6);
                }
            }else{
                gatewayOnLineVos.get(a).setState(6);
            }
            String sql ="SELECT \"battery\" FROM \"tdl_policy\".\""+device+"\" ORDER BY time DESC LIMIT 1";
            QueryResult queryResult = influxDBTemplate.query(new Query(sql, database));
            if (queryResult.getResults().get(0).getSeries() != null) {
                gatewayOnLineVos.get(a).setBattery(queryResult.getResults().get(0).getSeries().get(0).getValues().get(0).get(1).toString());
            }else {
                gatewayOnLineVos.get(a).setBattery("");
            }
            List<String> tdls=tdlDeviceService.getByGatewaySN(gatewayOnLineVos.get(a).getSN(),gatewayOnLineVos.get(a).getType());
            List<TDLDeviceDetailVo> tdlDeviceDetailVos=new ArrayList<>();
            for (int b=0;b<tdls.size();b++){
                TDLDeviceDetailVo tdlDeviceDetailVo=new TDLDeviceDetailVo();
                String sqls ="SELECT \"b\", \"T\", \"h\" FROM \"tdl_policy\".\""+device+"\" WHERE (\"tdl\" = '"+tdls.get(b)+"') ORDER BY time DESC LIMIT 1";
                QueryResult queryResults = influxDBTemplate.query(new Query(sqls, database));
                if (queryResults.getResults().get(0).getSeries() != null) {
                    tdlDeviceDetailVo.setTime(parseTime(queryResults.getResults().get(0).getSeries().get(0).getValues().get(0).get(0).toString()));
                    tdlDeviceDetailVo.setPressure(queryResults.getResults().get(0).getSeries().get(0).getValues().get(0).get(1).toString());
                    tdlDeviceDetailVo.setTemperature(queryResults.getResults().get(0).getSeries().get(0).getValues().get(0).get(2).toString());
                    tdlDeviceDetailVo.setHumidity(queryResults.getResults().get(0).getSeries().get(0).getValues().get(0).get(3).toString());
                }else{
                    tdlDeviceDetailVo.setTime("");
                    tdlDeviceDetailVo.setPressure("");
                    tdlDeviceDetailVo.setPressure("");
                    tdlDeviceDetailVo.setHumidity("");
                }
                tdlDeviceDetailVo.setTDLSN(tdls.get(b));
                tdlDeviceDetailVos.add(tdlDeviceDetailVo);
            }
            gatewayOnLineVos.get(a).setTdlDeviceDetailVos(tdlDeviceDetailVos);
        }
        warehouseDetailVo.setGatewayOnLineVos(gatewayOnLineVos);
        return warehouseDetailVo;
    }

    //获取某个仓库的网关
    @ApiOperation(value="添加网关",notes = "添加网关，传值:" +
            "warehouseNo:仓库编号" +
            "SN:网关编号")
    @ApiImplicitParams({
            @ApiImplicitParam(paramType="header", name = "Account_token", value = "token", required = true, dataType = "String"),
    })
    @PostMapping("/getGateway")
    public Object getGateway(@RequestBody String warehouseNo, HttpServletRequest request){
        String token = request.getHeader("Account_token");
        String datum = tokenRedisService.get("TOKEN_" +token);
        UserRedisVo user = gson.fromJson(datum,UserRedisVo.class);
        if (StringUtils.isEmpty(warehouseNo)){
            fb.setCode(0);
            fb.setMessage("仓库编号不能为空");
            return gson.toJson(fb);
        }
        JSONObject jsonObject= JSON.parseObject(warehouseNo);
        warehouseNo=(String)jsonObject.get("warehouseNo");
        if(warehouseService.getWarehouseNo(warehouseNo) ==0){
            fb.setCode(0);
            fb.setMessage("仓库编号不存在");
            return gson.toJson(fb);
        }
        //获取网关编号
        return warehouseService.getGateway(warehouseNo);
    }

    //添加仓库信息
    @ApiOperation(value = "添加仓库信息",notes = "添加仓库信息,传值说明：" +
            "   warehouseName:仓库名," +
            "   country:国家," +
            "   city:市," +
            "   addressDetail:具体地址," +
            "   regionName:区域名," +
            "   property:属性," +
            "   type:类型," +
            "   alarmType:预警类型," +
            "   hardwareLevel:硬件等级," +
            "   areaIndoor:室内平面面积," +
            "   areaRack:货架面积," +
            "   areaOutdoor:室外面积," +
            "   areaPlanIndoor:实际室内总面积," +
            "   office:办事处," +
            "   timeZone:时区," +
            "   warehouseInfo:基础描述," +
            "   remark:备注")
    @ApiImplicitParams({
            @ApiImplicitParam(paramType="header", name = "Account_token", value = "token", required = true, dataType = "String"),
    })
    @RequestMapping(value="/addWarehouse",method = RequestMethod.POST)
    public Object addWarehouse(@RequestBody AddWarehouseVo addWarehouseVo, HttpServletRequest request){
        String token = request.getHeader("Account_token");
        String datum = tokenRedisService.get("TOKEN_" +token);
        UserRedisVo user = gson.fromJson(datum,UserRedisVo.class);
        String warehouseNo = getWarehouseNo();
        if(StringUtils.isEmpty(addWarehouseVo.getImg())){
            fb.setCode(0);
            fb.setMessage("仓库图片不能为空");
            return gson.toJson(fb);
        }
        if (StringUtils.isEmpty(addWarehouseVo.getWarehouseName())){
            fb.setCode(0);
            fb.setMessage("仓库名不能为空");
            return gson.toJson(fb);
        }
        if (StringUtils.isEmpty(addWarehouseVo.getCountry())){
            fb.setCode(0);
            fb.setMessage(i18n.getMessage(request,"country"));
            return gson.toJson(fb);
        }
        if (StringUtils.isEmpty(addWarehouseVo.getCity())){
            fb.setCode(0);
            fb.setMessage(i18n.getMessage(request,"city"));
            return gson.toJson(fb);
        }
        if (StringUtils.isEmpty(addWarehouseVo.getAddressDetail())){
            fb.setCode(0);
            fb.setMessage(i18n.getMessage(request,"addressDetail"));
            return gson.toJson(fb);
        }
        if (StringUtils.isEmpty(addWarehouseVo.getRegionName())) {
            fb.setCode(0);
            fb.setMessage("区域不能为空");
            return gson.toJson(fb);
        }
        if (StringUtils.isEmpty(addWarehouseVo.getLat())){
            fb.setCode(0);
            fb.setMessage(i18n.getMessage(request,"lat"));
            return gson.toJson(fb);
        }
        if (StringUtils.isEmpty(addWarehouseVo.getLng())){
            fb.setCode(0);
            fb.setMessage(i18n.getMessage(request,"lng"));
            return gson.toJson(fb);
        }
        if(!addWarehouseVo.getLat().matches("^-?(([1-9])((\\.\\d{1,6})?)|([1-8]\\d)((\\.\\d{1,6})?)|90)$")){
            fb.setCode(0);
            fb.setMessage(i18n.getMessage(request,"wrongLat"));
            return gson.toJson(fb);
        }
        if(!addWarehouseVo.getLng().matches("^-?(([1-9]\\d?)((\\.\\d{1,6})?)|(1[1-7]\\d)((\\.\\d{1,6})?)|180)$")) {
            fb.setCode(0);
            fb.setMessage(i18n.getMessage(request,"wrongLng"));
            return gson.toJson(fb);
        }
        if (StringUtils.isEmpty(addWarehouseVo.getProperty())){
            fb.setCode(0);
            fb.setMessage("仓库属性不能为空");
            return gson.toJson(fb);
        }
        if (!"供应中心".equals(addWarehouseVo.getProperty())&&!"项目仓".equals(addWarehouseVo.getProperty())&&
                !"中心仓".equals(addWarehouseVo.getProperty())&&!"X-dock".equals(addWarehouseVo.getProperty())){
            fb.setCode(0);
            fb.setMessage("请输入正确的属性");
            return gson.toJson(fb);
        }
        if (StringUtils.isEmpty(addWarehouseVo.getType())){
            fb.setCode(0);
            fb.setMessage("仓库类型不能为空");
            return gson.toJson(fb);
        }
        if (!addWarehouseVo.getType().equals("平面仓")&&!addWarehouseVo.getType().equals("立体仓")){
            fb.setCode(0);
            fb.setMessage("请输入正确的仓库类型");
            return gson.toJson(fb);
        }
        if (StringUtils.isEmpty(addWarehouseVo.getAlarmType())){
            fb.setCode(0);
            fb.setMessage(i18n.getMessage(request,"alarmType"));
            return gson.toJson(fb);
        }
        if(alarmService.getAllByAlarmType(user.getCompanyName(),addWarehouseVo.getAlarmType()) == null){
            fb.setCode(0);
            fb.setMessage("预警类型不存在");
            return gson.toJson(fb);
        }
        if (StringUtils.isEmpty(addWarehouseVo.getHardwareLevel())){
            fb.setCode(0);
            fb.setMessage("硬件等级不能为空");
            return gson.toJson(fb);
        }
        if (!addWarehouseVo.getHardwareLevel().equals("好")&&!addWarehouseVo.getHardwareLevel().equals("一般")&&
                !addWarehouseVo.getHardwareLevel().equals("较差")&&!addWarehouseVo.getHardwareLevel().equals("极差")){
            fb.setCode(0);
            fb.setMessage("请选择正确的硬件等级");
            return gson.toJson(fb);
        }
        if (addWarehouseVo.getAreaIndoor()==null){
            fb.setCode(0);
            fb.setMessage("室内平面面积不能为空");
            return gson.toJson(fb);
        }
        if (addWarehouseVo.getAreaRack()==null){
            fb.setCode(0);
            fb.setMessage("货架面积不能为空");
            return gson.toJson(fb);
        }
        if (addWarehouseVo.getAreaOutdoor()==null){
            fb.setCode(0);
            fb.setMessage("室外面积不能为空");
            return gson.toJson(fb);
        }
        if (addWarehouseVo.getAreaPlanIndoor() == null){
            fb.setCode(0);
            fb.setMessage("实际室内总面积不能为空");
            return gson.toJson(fb);
        }
        if (StringUtils.isEmpty(addWarehouseVo.getOffice())){
            fb.setCode(0);
            fb.setMessage("办事处不能为空");
            return gson.toJson(fb);
        }
        if (addWarehouseVo.getTimeZone()==null){
            fb.setCode(0);
            fb.setMessage("时区不能为空");
            return gson.toJson(fb);
        }
        if (warehouseService.getByWarehouseName(addWarehouseVo.getWarehouseName(),user.getCompanyName())!=null){
            fb.setCode(0);
            fb.setMessage("仓库名不能重复");
            return gson.toJson(fb);
        }
        Map<Object,Object> map=new HashMap<>();
        map.put("warehouseNo",warehouseNo);
        map.put("warehouseName",addWarehouseVo.getWarehouseName());
        map.put("country",addWarehouseVo.getCountry());
        map.put("city",addWarehouseVo.getCity());
        map.put("addressDetail",addWarehouseVo.getAddressDetail());
        map.put("lng",addWarehouseVo.getLng());
        map.put("lat",addWarehouseVo.getLat());
        map.put("regionName",addWarehouseVo.getRegionName());
        map.put("property",addWarehouseVo.getProperty());
        map.put("type",addWarehouseVo.getType());
        map.put("alarmType",addWarehouseVo.getAlarmType());
        map.put("hardwareLevel",addWarehouseVo.getHardwareLevel());
        map.put("areaIndoor",addWarehouseVo.getAreaIndoor());
        map.put("areaRack",addWarehouseVo.getAreaRack());
        map.put("areaOutdoor",addWarehouseVo.getAreaOutdoor());
        map.put("areaPlanIndoor",addWarehouseVo.getAreaPlanIndoor());
        map.put("office",addWarehouseVo.getOffice());
        map.put("timeZone",addWarehouseVo.getTimeZone());
        map.put("warehouseInfo",addWarehouseVo.getWarehouseInfo() == null ? "" :addWarehouseVo.getWarehouseInfo());
        map.put("companyName",user.getCompanyName());
        map.put("createTime",System.currentTimeMillis());
        map.put("updateTime",System.currentTimeMillis());
        map.put("img",addWarehouseVo.getImg());
        map.put("remark",addWarehouseVo.getRemark()== null ? "" :addWarehouseVo.getRemark());
        warehouseService.addWarehouse(map);
        Map<Object,Object> msg=new HashMap<>();
        msg.put("msg",map.get("msg"));
        if(msg.get("msg").equals("添加仓库成功")){
            fb.setCode(1);
            fb.setMessage(msg.get("msg").toString());
        }else{
            fb.setCode(0);
            fb.setMessage(msg.get("msg").toString());
        }
        return gson.toJson(fb);

    }

    //根据仓库编号修改仓库信息
    @ApiOperation(value = "根据仓库编号修改仓库信息",notes = "根据仓库编号修改仓库信息,updatTime不用传，传值说明：" +
            "   warehouseNo:需要修改的仓库编号," +
            "   warehouseName:仓库名," +
            "   country:国家," +
            "   province:省," +
            "   city:市," +
            "   district:区," +
            "   address:具体地址," +
            "   regionCN:区域中文," +
            "   regionEN:区域英文," +
            "   longitude:经度," +
            "   latitude:纬度," +
            "   property:属性," +
            "   type:类型," +
            "   alarmType:预警类型," +
            "   hardwareLevel:硬件等级," +
            "   areaIndoor:室内平面面积," +
            "   areaRack:货架面积," +
            "   areaOutdoor:室外面积," +
            "   areaPlanIndoor:实际室内总面积," +
            "   office:办事处," +
            "   timeZone:时区," +
            "   weatherInfo:区域气象信息," +
            "   warehouseInfo:基础描述," +
            "   remark:备注")
    @ApiImplicitParams({
            @ApiImplicitParam(paramType="header", name = "Account_token", value = "token", required = true, dataType = "String"),
    })
    @RequestMapping(value="/updateWarehouse",method = RequestMethod.POST)
    public Object updateWarehouse(@RequestBody UpdateWarehouseVo updateWarehouseVo,HttpServletRequest request){
        String token = request.getHeader("Account_token");
        String datum = tokenRedisService.get("TOKEN_" +token);
        UserRedisVo user = gson.fromJson(datum,UserRedisVo.class);
        if (StringUtils.isEmpty(updateWarehouseVo.getWarehouseNo())){
            fb.setCode(0);
            fb.setMessage("需要修改的仓库编号不能为空");
            return gson.toJson(fb);
        }
        if (StringUtils.isEmpty(updateWarehouseVo.getWarehouseName())){
            fb.setCode(0);
            fb.setMessage("仓库名不能为空");
            return gson.toJson(fb);
        }
        if (StringUtils.isEmpty(updateWarehouseVo.getCountry())){
            fb.setCode(0);
            fb.setMessage("国家不能为空");
            return gson.toJson(fb);
        }
        if (StringUtils.isEmpty(updateWarehouseVo.getCity())){
            fb.setCode(0);
            fb.setMessage("市不能为空");
            return gson.toJson(fb);
        }
        if (StringUtils.isEmpty(updateWarehouseVo.getAddressDetail())){
            fb.setCode(0);
            fb.setMessage("具体地址不能为空");
            return gson.toJson(fb);
        }
        if (StringUtils.isEmpty(updateWarehouseVo.getRegionName())){
            fb.setCode(0);
            fb.setMessage("区域不能为空");
            return gson.toJson(fb);
        }
        if (StringUtils.isEmpty(updateWarehouseVo.getLat())){
            fb.setCode(0);
            fb.setMessage("纬度不能为空");
            return gson.toJson(fb);
        }
        if (StringUtils.isEmpty(updateWarehouseVo.getLng())){
            fb.setCode(0);
            fb.setMessage("经度不能为空");
            return gson.toJson(fb);
        }
        if(!updateWarehouseVo.getLat().matches("^-?(([1-9])((\\.\\d{1,6})?)|([1-8]\\d)((\\.\\d{1,6})?)|90)$")){
            fb.setCode(0);
            fb.setMessage("纬度的范围为-90~90");
            return gson.toJson(fb);
        }
        if(!updateWarehouseVo.getLng().matches("^-?(([1-9]\\d?)((\\.\\d{1,6})?)|(1[1-7]\\d)((\\.\\d{1,6})?)|180)$")) {
            fb.setCode(0);
            fb.setMessage("经度的范围为-180~180");
            return gson.toJson(fb);
        }
        if (StringUtils.isEmpty(updateWarehouseVo.getProperty())){
            fb.setCode(0);
            fb.setMessage("仓库属性不能为空");
            return gson.toJson(fb);
        }
        if (!updateWarehouseVo.getProperty().equals("供应中心")&&!updateWarehouseVo.getProperty().equals("项目仓")&&
                !updateWarehouseVo.getProperty().equals("中心仓")&&!updateWarehouseVo.getProperty().equals("X-dock")){
            fb.setCode(0);
            fb.setMessage("请输入正确的仓库属性");
            return gson.toJson(fb);
        }
        if (StringUtils.isEmpty(updateWarehouseVo.getType())){
            fb.setCode(0);
            fb.setMessage("仓库类型不能为空");
            return gson.toJson(fb);
        }
        if (!"平面仓".equals(updateWarehouseVo.getType())&&!"立体仓".equals(updateWarehouseVo.getType())){
            fb.setCode(0);
            fb.setMessage("请输入正确的仓库仓库类型");
            return gson.toJson(fb);
        }
        if (StringUtils.isEmpty(updateWarehouseVo.getAlarmType())){
            fb.setCode(0);
            fb.setMessage("预警类型不能为空");
            return gson.toJson(fb);
        }
        if (StringUtils.isEmpty(updateWarehouseVo.getHardwareLevel())){
            fb.setCode(0);
            fb.setMessage("硬件等级不能为空");
            return gson.toJson(fb);
        }
        if (!updateWarehouseVo.getHardwareLevel().equals("好")&&!updateWarehouseVo.getHardwareLevel().equals("一般")&&
                !updateWarehouseVo.getHardwareLevel().equals("较差")&&!updateWarehouseVo.getHardwareLevel().equals("极差")){
            fb.setCode(0);
            fb.setMessage("请选择正确的硬件等级");
            return gson.toJson(fb);
        }
        if (updateWarehouseVo.getAreaIndoor() == null){
            fb.setCode(0);
            fb.setMessage("室内平面面积不能为空");
            return gson.toJson(fb);
        }
        if (updateWarehouseVo.getAreaRack()== null){
            fb.setCode(0);
            fb.setMessage("货架面积不能为空");
            return gson.toJson(fb);
        }
        if (updateWarehouseVo.getAreaOutdoor()== null){
            fb.setCode(0);
            fb.setMessage("室外面积不能为空");
            return gson.toJson(fb);
        }
        if (updateWarehouseVo.getAreaPlanIndoor()== null){
            fb.setCode(0);
            fb.setMessage("实际室内总面积不能为空");
            return gson.toJson(fb);
        }
        if (StringUtils.isEmpty(updateWarehouseVo.getOffice())){
            fb.setCode(0);
            fb.setMessage("办事处不能为空");
            return gson.toJson(fb);
        }
        if (updateWarehouseVo.getTimeZone()== null){
            fb.setCode(0);
            fb.setMessage("时区不能为空");
            return gson.toJson(fb);
        }
        ResultWarehouseVo resultWarehouseVo=warehouseService.getByWarehouseName(updateWarehouseVo.getWarehouseName(),user.getCompanyName());
        if (resultWarehouseVo!=null&&!resultWarehouseVo.getWarehouseNo().equals(updateWarehouseVo.getWarehouseNo())){
            fb.setCode(0);
            fb.setMessage("修改的仓库名已存在");
            return gson.toJson(fb);
        }
        Map<Object,Object> map=new HashMap<>();
        map.put("warehouseNo",updateWarehouseVo.getWarehouseNo());
        map.put("warehouseName",updateWarehouseVo.getWarehouseName());
        map.put("country",updateWarehouseVo.getCountry());
        map.put("city",updateWarehouseVo.getCity());
        map.put("addressDetail",updateWarehouseVo.getAddressDetail());
        map.put("lng",updateWarehouseVo.getLng());
        map.put("lat",updateWarehouseVo.getLat());
        map.put("regionName",updateWarehouseVo.getRegionName());
        map.put("property",updateWarehouseVo.getProperty());
        map.put("type",updateWarehouseVo.getType());
        map.put("alarmType",updateWarehouseVo.getAlarmType());
        map.put("hardwareLevel",updateWarehouseVo.getHardwareLevel());
        map.put("areaIndoor",updateWarehouseVo.getAreaIndoor());
        map.put("areaRack",updateWarehouseVo.getAreaRack());
        map.put("areaOutdoor",updateWarehouseVo.getAreaOutdoor());
        map.put("areaPlanIndoor",updateWarehouseVo.getAreaPlanIndoor());
        map.put("office",updateWarehouseVo.getOffice());
        map.put("timeZone",updateWarehouseVo.getTimeZone());
        map.put("warehouseInfo",updateWarehouseVo.getWarehouseInfo());
        map.put("companyName",user.getCompanyName());
        map.put("updateTime",System.currentTimeMillis());
        map.put("remark",updateWarehouseVo.getRemark());
        warehouseService.updateWarehouse(map);
        Map<Object,Object> msg=new HashMap<>();
        msg.put("msg",map.get("msg"));
        if(msg.get("msg").equals("修改仓库成功")){
            fb.setCode(1);
            fb.setMessage(msg.get("msg").toString());
        }else{
            fb.setCode(0);
            fb.setMessage(msg.get("msg").toString());
        }
        return gson.toJson(fb);
    }

    //删除仓库信息
    @ApiOperation(value = "删除仓库信息",notes = "删除仓库信息,只用传仓库编号")
    @ApiImplicitParams({
            @ApiImplicitParam(paramType="header", name = "Account_token", value = "token", required = true, dataType = "String"),
    })
    @RequestMapping(value="/delWarehouse",method = RequestMethod.POST)
    public Object delWarehouse(@RequestBody String warehouseNo, HttpServletRequest request){
        String token = request.getHeader("Account_token");
        String datum = tokenRedisService.get("TOKEN_" +token);
        UserRedisVo user = gson.fromJson(datum,UserRedisVo.class);
        if (StringUtils.isEmpty(warehouseNo)){
            fb.setCode(0);
            fb.setMessage("需要删除的仓库编号不能为空");
            return gson.toJson(fb);
        }
        JSONObject jsonObject= JSON.parseObject(warehouseNo);
        warehouseNo=(String)jsonObject.get("warehouseNo");
        if(warehouseService.getWarehouseNo(warehouseNo) ==0){
            fb.setCode(0);
            fb.setMessage("仓库编号不存在");
            return gson.toJson(fb);
        }
        Map<Object,Object> map=new HashMap<>();
        map.put("warehouseNo",warehouseNo);
        map.put("companyName",user.getCompanyName());
        map.put("endTime",System.currentTimeMillis());
        warehouseService.delWarehouse(map);
        Map<Object,Object> msg=new HashMap<>();
        msg.put("msg",map.get("msg"));
        if(msg.get("msg").equals("仓库删除成功")){
            fb.setCode(1);
            fb.setMessage(msg.get("msg").toString());
        }else{
            fb.setCode(0);
            fb.setMessage(msg.get("msg").toString());
        }
        return gson.toJson(fb);
    }

    @ApiOperation(value="添加网关",notes = "添加网关，传值:" +
            "warehouseNo:仓库编号" +
            "SN:网关编号")
    @ApiImplicitParams({
            @ApiImplicitParam(paramType="header", name = "Account_token", value = "token", required = true, dataType = "String"),
    })
    @PostMapping("/addGateway")
    public Object addGateway(@RequestBody AddWarehouseGatewayVo addWarehouseGatewayVo,HttpServletRequest request){
        String token = request.getHeader("Account_token");
        String datum = tokenRedisService.get("TOKEN_" +token);
        UserRedisVo user = gson.fromJson(datum,UserRedisVo.class);
        if (StringUtils.isEmpty(addWarehouseGatewayVo.getWarehouseNo())){
            fb.setCode(0);
            fb.setMessage("仓库编号不能为空");
            return gson.toJson(fb);
        }
        if(warehouseService.getWarehouseNo(addWarehouseGatewayVo.getWarehouseNo()) ==0){
            fb.setCode(0);
            fb.setMessage("仓库编号不存在");
            return gson.toJson(fb);
        }
        if (StringUtils.isEmpty(addWarehouseGatewayVo.getSN())){
            fb.setCode(0);
            fb.setMessage("网关编号不能为空");
            return gson.toJson(fb);
        }
        if( gatewayService.getBySN(addWarehouseGatewayVo.getSN(),user.getCompanyNo())==null){
            fb.setCode(0);
            fb.setMessage("该网关不存在");
            return gson.toJson(fb);
        }
        //判断当前网关是否已经被使用
        Map<Object,Object> map=new HashMap<>();
        map.put("warehouseNo",addWarehouseGatewayVo.getWarehouseNo());
        map.put("gSN",addWarehouseGatewayVo.getSN());
        map.put("gType","WTD93LG");
        map.put("startTime",System.currentTimeMillis());
        warehouseService.addGateway(map);
        Map<Object,Object> msg=new HashMap<>();
        msg.put("msg",map.get("msg"));
        if(msg.get("msg").equals("添加网关成功")){
            fb.setCode(1);
            fb.setMessage(msg.get("msg").toString());
        }else{
            fb.setCode(0);
            fb.setMessage(msg.get("msg").toString());
        }
        return gson.toJson(fb);
    }

    //绑定报警联系人
    @ApiOperation(value="绑定报警联系人",notes = "绑定报警联系人，传值:" +
            "warehouseNo:仓库编号" +
            "userNameList:用户名的集合")
    @ApiImplicitParams({
            @ApiImplicitParam(paramType="header", name = "Account_token", value = "token", required = true, dataType = "String"),
    })
    @PostMapping("/addUser")
    public Object addUser(@RequestBody WarehouseUserVo warehouseUserVo, HttpServletRequest request){
        String token = request.getHeader("Account_token");
        String datum = tokenRedisService.get("TOKEN_" +token);
        UserRedisVo user = gson.fromJson(datum,UserRedisVo.class);
        if (StringUtils.isEmpty(warehouseUserVo.getWarehouseNo())){
            fb.setCode(0);
            fb.setMessage("仓库编号不能为空");
            return gson.toJson(fb);
        }
        if(warehouseService.getWarehouseNo(warehouseUserVo.getWarehouseNo()) ==0){
            fb.setCode(0);
            fb.setMessage("仓库编号不存在");
            return gson.toJson(fb);
        }
        if (warehouseUserVo.getUserNameList().size() == 0){
            fb.setCode(0);
            fb.setMessage("用户不能为空");
            return gson.toJson(fb);
        }
        String userNameVar = "";
        for(int i = 0,length=warehouseUserVo.getUserNameList().size();i<length;i++){
            if(userService.getByUserName(warehouseUserVo.getUserNameList().get(i).getUserName()) == null){
                fb.setCode(0);
                fb.setMessage("用户名不存在");
                return gson.toJson(fb);
            }
            userNameVar = userNameVar +warehouseUserVo.getUserNameList().get(i).getUserName() +" ";
        }
        Map<Object,Object> map=new HashMap<>();
        map.put("warehouseNo",warehouseUserVo.getWarehouseNo());
        map.put("number",warehouseUserVo.getUserNameList().size());
        map.put("userNameVar",userNameVar);
        warehouseService.addUser(map);
        Map<Object,Object> msg=new HashMap<>();
        msg.put("msg",map.get("msg"));
        if(msg.get("msg").equals("添加紧急联系人成功")){
            fb.setCode(1);
            fb.setMessage(msg.get("msg").toString());
        }else{
            fb.setCode(0);
            fb.setMessage(msg.get("msg").toString());
        }
        return  gson.toJson(fb);
    }


    //根据仓库编号获取仓库实时数据
    @ApiOperation(value = "根据仓库编号获取仓库信息",notes = "根据仓库编号获取仓库信息,传值说明：")
    @ApiImplicitParams({
            @ApiImplicitParam(paramType="header", name = "Account_token", value = "token", required = true, dataType = "String"),
    })
    @PostMapping("/getWarehouseData")
    public Object getWarehouseData(@RequestBody String warehouseNo,HttpServletRequest request){
        JSONObject jsonObject=JSON.parseObject(warehouseNo);
        warehouseNo=(String) jsonObject.get("warehouseNo");
        List<WarehouseGatewayDateVo> warehouseGatewayDateVoList=new ArrayList<>();
        List<GatewayOnLineVo> gatewayOnLineVos=gatewayService.getByWarehouseNo(warehouseNo);
        ResultAlarmVo resultAlarmVo=alarmService.getAlarmByWarehouseNo(warehouseNo);
        for (int a=0;a<gatewayOnLineVos.size();a++){
            WarehouseGatewayDateVo warehouseGatewayDateVo=new WarehouseGatewayDateVo();
            warehouseGatewayDateVo.setgSN(gatewayOnLineVos.get(a).getSN());
            warehouseGatewayDateVo.setType(gatewayOnLineVos.get(a).getType());
            warehouseGatewayDateVo.setTemMax(resultAlarmVo.getTemMax());
            warehouseGatewayDateVo.setTemMin(resultAlarmVo.getTemMin());
            warehouseGatewayDateVo.setHumidityMax(resultAlarmVo.getHumidityMax());
            warehouseGatewayDateVo.setHumidityMin(resultAlarmVo.getHumidityMin());
            String device = gatewayOnLineVos.get(a).getType() + "_" + gatewayOnLineVos.get(a).getSN();
            List<String> tdls=tdlDeviceService.getByGatewaySN(gatewayOnLineVos.get(a).getSN(),gatewayOnLineVos.get(a).getType());
            List<WarehouseDataVo> warehouseDataVos=new ArrayList<>();
            for (int b=0;b<tdls.size();b++){
//                String sqls ="SELECT \"tdl\",\"T\", \"h\" FROM \"tdl_policy\".\""+device+"\" WHERE (\"tdl\" = '"+tdls.get(b)+"') ORDER BY time DESC ";
                String sqls ="SELECT \"tdl\",\"T\", \"h\" FROM \"tdl_policy\".\"WTD93LG_17110194\" WHERE (\"tdl\" = 'TDL-1701110082608') ORDER BY time DESC ";
                QueryResult queryResults = influxDBTemplate.query(new Query(sqls, database));
                WarehouseDataVo warehouseDataVo=new WarehouseDataVo();
                List<WarehouseTDLDetailVo> warehouseTDLDetailVos=new ArrayList<>();

                List<WarehouseTimeAndDataVo>  warehouseTimeAndDataVos = new ArrayList<>();
                List<WarehouseTimeAndDataVo>  warehouseTimeAndDataVos1 = new ArrayList<>();
                if(queryResults.getResults().get(0).getSeries() != null){
                    //解析数据
                    WarehouseTDLDetailVo warehouseTDLDetailVo=new WarehouseTDLDetailVo();
                    warehouseTimeAndDataVos = getData(queryResults);
                    warehouseTDLDetailVo.setDescription("temperature");
                    warehouseTDLDetailVo.setTimeAndValuesVos(warehouseTimeAndDataVos);
                    warehouseTDLDetailVos.add(warehouseTDLDetailVo);

                    WarehouseTDLDetailVo warehouseTDLDetailVo1=new WarehouseTDLDetailVo();
                    warehouseTimeAndDataVos1 = getDatas(queryResults);
                    warehouseTDLDetailVo1.setDescription("humidity");
                    warehouseTDLDetailVo1.setTimeAndValuesVos(warehouseTimeAndDataVos1);
                    warehouseTDLDetailVos.add(warehouseTDLDetailVo1);
                }
                warehouseDataVo.setTDLSN(tdls.get(b));
                warehouseDataVo.setWarehouseTDLDetailVos(warehouseTDLDetailVos);
                warehouseDataVos.add(warehouseDataVo);
            }
            warehouseGatewayDateVo.setWarehouseDataVos(warehouseDataVos);
            warehouseGatewayDateVoList.add(warehouseGatewayDateVo);
        }
        return warehouseGatewayDateVoList;
    }


    public List<WarehouseTimeAndDataVo> getData(QueryResult queryResult){
        List<List<Object>> values = getValues(queryResult);
        List<WarehouseTimeAndDataVo> historyDataList = new ArrayList<>();
        for(List<Object> value:values){
            WarehouseTimeAndDataVo warehouseTimeAndDataVo = new WarehouseTimeAndDataVo();
            warehouseTimeAndDataVo.setTime(parseTime(value.get(0).toString()));
            warehouseTimeAndDataVo.setValue(value.get(2)==null  ? "" :value.get(2).toString());
            historyDataList.add(warehouseTimeAndDataVo);
        }
        return historyDataList;
    }

    public List<WarehouseTimeAndDataVo> getDatas(QueryResult queryResult){
        List<List<Object>> values = getValues(queryResult);
        List<WarehouseTimeAndDataVo> historyDataList = new ArrayList<>();
        for(List<Object> value:values){
            WarehouseTimeAndDataVo warehouseTimeAndDataVo = new WarehouseTimeAndDataVo();
            warehouseTimeAndDataVo.setTime(parseTime(value.get(0).toString()));
            warehouseTimeAndDataVo.setValue(value.get(3)==null ? "" :value.get(3).toString());
            historyDataList.add(warehouseTimeAndDataVo);
        }
        return historyDataList;
    }

    //解析数据格式
    public List<List<Object>>  getValues( QueryResult  queryResult){
        List<List<Object>> values = new ArrayList<>();
        for(QueryResult.Result result : queryResult.getResults()){
            if(result.getSeries() !=null){
                for (QueryResult.Series series : result.getSeries()) {
                    if(series !=null){
                        values= series.getValues();
                    }
                }
            }
        }
        return values;
    }

    //货物仓库某一tdl的温湿度
    @ApiOperation(value="绑定报警联系人",notes = "绑定报警联系人，传值:" +
            "warehouseNo:仓库编号" +
            "userNameList:用户名的集合")
    @ApiImplicitParams({
            @ApiImplicitParam(paramType="header", name = "Account_token", value = "token", required = true, dataType = "String"),
    })
    @PostMapping("/getTdlData")
    public Object getTdlData(@RequestBody SearchTdlVo searchTdlVo ,HttpServletRequest request){
        if (StringUtils.isEmpty(searchTdlVo.getWarehouseNo())){
            fb.setCode(0);
            fb.setMessage("仓库编号不能为空");
            return gson.toJson(fb);
        }
        if(warehouseService.getWarehouseNo(searchTdlVo.getWarehouseNo()) ==0){
            fb.setCode(0);
            fb.setMessage("仓库编号不存在");
            return gson.toJson(fb);
        }
        //判断网关和tdl是否存在
        if (StringUtils.isEmpty(searchTdlVo.getGatewaySN())) {
            fb.setCode(0);
            fb.setMessage("网关编号不能为空");
            return gson.toJson(fb);
        }
        if(StringUtils.isEmpty(searchTdlVo.getTdlSN())) {
            fb.setCode(0);
            fb.setMessage("传感器编号不能为空");
            return gson.toJson(fb);
        }
        //获取tdl的信息

        TdlDataVo tdlDataVo = new TdlDataVo();
        List<GraphicDataVo>  graphicDataList = new ArrayList<>();
        List<TdlDataVo.HistoryDataVo> historyDataList = new ArrayList<>();
        //获取TDL数据
//        String sql = "SELECT \"T\",\"h\" FROM \"tdl_policy\".\"WTD93LG_17110194\"  where  \"tdl\" = \'TDL-"+searchTdlVo.getTdlSN()+"\'  order by time ";
        String sql = "SELECT \"T\",\"h\" FROM \"tdl_policy\".\"WTD93LG_17110194\"  where  \"tdl\" = \'TDL-1706190193608\' order by time ";
        QueryResult queryResult = influxDBTemplate.query(new Query(sql,database));
        if(queryResult.getResults().get(0).getSeries()== null){
            tdlDataVo.setGraphicDataList(graphicDataList);
            tdlDataVo.setHistoryDataList(historyDataList);
        }
        tdlDataVo =   parseData(queryResult);
        return  tdlDataVo;
    }



    //根据仓库获取用户
    @ApiOperation(value="获取报警联系人",notes = "获取报警联系人，传值:仓库编号")
    @ApiImplicitParams({
            @ApiImplicitParam(paramType="header", name = "Account_token", value = "token", required = true, dataType = "String"),
    })
    @PostMapping("/getAlarmContacts")
    public Object getAlarmContacts(@RequestBody String warehouseNo ,HttpServletRequest request){
        String token = request.getHeader("Account_token");
        String datum = tokenRedisService.get("TOKEN_" +token);
        UserRedisVo user = gson.fromJson(datum,UserRedisVo.class);
        if (StringUtils.isEmpty(warehouseNo)){
            fb.setCode(0);
            fb.setMessage("仓库编号不能为空");
            return gson.toJson(fb);
        }
        JSONObject jsonObject= JSON.parseObject(warehouseNo);
        warehouseNo=(String)jsonObject.get("warehouseNo");
        if(warehouseService.getWarehouseNo(warehouseNo) ==0){
            fb.setCode(0);
            fb.setMessage("仓库编号不存在");
            return gson.toJson(fb);
        }
        return   warehouseService.getAlarmContacts(warehouseNo);
    }




    //生成仓库编号
    public String getWarehouseNo(){
        String warehouseNo = "WH" +System.currentTimeMillis() ;
        warehouseNo = warehouseNo +((int)(Math.random()*(9999-1000+1))+1000);
        if (warehouseService.getWarehouseNo(warehouseNo)>0){
            while (warehouseService.getWarehouseNo(warehouseNo)>0){
                warehouseNo=warehouseNo+((int)(Math.random()*(9999-1000+1))+1000);
            }
        }
        return warehouseNo;
    }

    //解析时间
    public String parseTime(String time){
        String dateResult =null;
        try {
            dateResult = dateToStamp(time);
        } catch (ParseException e) {
            e.printStackTrace();
            logger.info(e.toString());
            fb.setCode(0);
            fb.setMessage("解析时间异常");
        }
        return dateResult;
    }

    //将utc时间转换成时间戳
    public static String dateToStamp(String s) throws ParseException {
        Date date =null ;
        if(s.length() !=20 ) {
            date = new SimpleDateFormat("yyyy-MM-dd'T'HH:mm:ss.SSS'Z'").parse(s);
        }else{
            date = new SimpleDateFormat("yyyy-MM-dd'T'HH:mm:ss'Z'").parse(s);
        }
        return String.valueOf(date.getTime());
    }

    public SimpleWarehouseVo  dataData(QueryResult queryResult){
        SimpleWarehouseVo simpleWarehouseVo = new SimpleWarehouseVo();
        List<List<Object>> value = new ArrayList<>();
        for(QueryResult.Result result : queryResult.getResults()){
            if(result.getSeries() !=null){
                for (QueryResult.Series series : result.getSeries()) {
                    if(series !=null){
                        value.add(series.getValues().get(0));
                    }else{
                        continue;
                    }
                }
            }else{
                continue;
            }
        }
        List<Double> tempList = new ArrayList<>();
        List<Double> humList = new ArrayList<>();
        for(int i = 0,length = value.size();i<length;i++){
            tempList.add(value.get(i).get(1)==null ? 0 :Double.valueOf(value.get(i).get(1).toString()));
            humList.add(value.get(i).get(2)==null ?  0 :Double.valueOf(value.get(i).get(2).toString()));
        }
        //设置数据
        simpleWarehouseVo.setTemp(getValue(tempList));
        simpleWarehouseVo.setHumidity(getValue(humList));
        return  simpleWarehouseVo;
    }

    public String  getValue(List<Double> data){
        String s = "";
        Collections.sort(data);
        if(data.size() == 1){
            if(data.get(0) == 0){
                return "~";
            }
            return data.get(0) +"~" +data.get(0);
        }else{
            if(data.get(0)!=0 && data.get(data.size()-1)!=0){
                return data.get(0) +"~" +data.get(data.size()-1);
            }else{
                for(int i=0;i<data.size();i++){
                    if(data.get(0)==0){
                        continue;
                    }else{
                        s=data.get(i).toString();
                    }
                }
                if(StringUtils.isEmpty(s)){
                    return "~";
                }
                return s+"~"+data.get(data.size()-1);
            }
        }
    }


   public  TdlDataVo parseData(QueryResult queryResult){
       TdlDataVo tdlDataVo = new TdlDataVo();
      List<List<Object>> values = new ArrayList<>();
       for(QueryResult.Result result : queryResult.getResults()){
           if(result.getSeries() !=null){
               for (QueryResult.Series series : result.getSeries()) {
                   if(series !=null){
                        values = series.getValues();
                   }else{
                       continue;
                   }
               }
           }else{
               continue;
           }
       }
       List<GraphicDataVo>  graphicDataList = new ArrayList<>();
       GraphicDataVo temp = new GraphicDataVo();
       temp.setDescption("temp");
       List<HistoryData> tempData = new ArrayList<>();
       GraphicDataVo hum = new GraphicDataVo();
       hum.setDescption("humidity");
       List<HistoryData> humpData = new ArrayList<>();
       List<TdlDataVo.HistoryDataVo> historyDataList = new ArrayList<>();
       for (int i =0,length = values.size();i<length;i++){
           TdlDataVo.HistoryDataVo historyDataVo = new TdlDataVo.HistoryDataVo();
           historyDataVo.setHumidity(values.get(i).get(2)==null ?"" :values.get(i).get(2).toString() );
           historyDataVo.setTemp(values.get(i).get(1)==null ?"" :values.get(i).get(1).toString() );
           String time =UTCToCST(values.get(i).get(0).toString());
           historyDataVo.setTime(Long.valueOf(time));
           historyDataList.add(historyDataVo);
           HistoryData tem = new HistoryData();
           tem.setTime(time);
           tem.setValue(values.get(i).get(1)==null ?"" :values.get(i).get(1).toString());
           tempData.add(tem);
           HistoryData hump = new HistoryData();
           hump.setTime(time);
           hump.setValue(values.get(i).get(2)==null ?"" :values.get(i).get(2).toString());
           humpData.add(hump);
       }
       temp.setHistoryDataList(tempData);
       hum.setHistoryDataList(humpData);
       graphicDataList.add(temp);
       graphicDataList.add(hum);
       tdlDataVo.setHistoryDataList(historyDataList);
       tdlDataVo.setGraphicDataList(graphicDataList);
       return  tdlDataVo;
    }

    public  String UTCToCST(String UTCStr) {
        Date date =null ;
        try {
            if (UTCStr.length() != 20) {
                date = new SimpleDateFormat("yyyy-MM-dd'T'HH:mm:ss.SSS'Z'").parse(UTCStr);
            } else {
                date = new SimpleDateFormat("yyyy-MM-dd'T'HH:mm:ss'Z'").parse(UTCStr);
            }
        }catch (Exception e){
            e.printStackTrace();
            logger.info(e.toString());
        }
        Calendar calendar = Calendar.getInstance();
        calendar.setTime(date);
        calendar.set(Calendar.HOUR, calendar.get(Calendar.HOUR) + 8);
        //calendar.getTime() 返回的是Date类型，也可以使用calendar.getTimeInMillis()获取时间戳
        //format的格式可以任意
        return String.valueOf(calendar.getTimeInMillis());
    }
}
